@@ -26,7 +26,7 @@ class AuthenticationServiceBase(FeatureImplementationBase, ABC):
         RequestedServer: str,
         RequestedFeatures: List[str],
         *,
-        metadata: Dict[FullyQualifiedIdentifier, Any]
+        metadata: Dict[FullyQualifiedIdentifier, Any],
     ) -> Login_Responses:
         """
         Provides an access token based on user information.
