@@ -22,7 +22,7 @@ class AuthorizationProviderServiceBase(FeatureImplementationBase, ABC):
         RequestedServer: str,
         RequestedFeature: str,
         *,
-        metadata: Dict[FullyQualifiedIdentifier, Any]
+        metadata: Dict[FullyQualifiedIdentifier, Any],
     ) -> Verify_Responses:
         """
         Verifies that a given token is valid for the requested server.
