@@ -179,7 +179,7 @@ class FeatureImplementationServicer:
             manager = self.__get_observable_command_manager(command_id, UUID(request.value), context)
 
             with raises_rpc_errors(context, self.logger):
-                for value in manager.subscribe_to_execution_infos():
+                for value in manager.subscribe_to_execution_infos(context):
                     yield value
 
         return wrapper
@@ -192,7 +192,7 @@ class FeatureImplementationServicer:
             manager = self.__get_observable_command_manager(command_id, UUID(request.value), context)
 
             with raises_rpc_errors(context, self.logger):
-                for value in manager.subscribe_to_intermediate_responses():
+                for value in manager.subscribe_to_intermediate_responses(context):
                     yield value
 
         return wrapper
@@ -233,7 +233,7 @@ class FeatureImplementationServicer:
                 queue = impl_func(metadata=metadata)
                 manager = self.__get_observable_property_subscription_thread_for_queue(prop, queue)
 
-                for value in manager.add_subscription():
+                for value in manager.add_subscription(context):
                     yield value
 
         return wrapper
