@@ -3,11 +3,14 @@ from __future__ import annotations
 import logging
 from queue import Queue
 from threading import Thread
-from typing import Callable, Generic, List, Optional, TypeVar
+from typing import TYPE_CHECKING, Callable, Generic, List, Optional, TypeVar
 
 from sila2.framework.fully_qualified_identifier import FullyQualifiedIdentifier
 from sila2.server.observables.stream import Stream
 
+if TYPE_CHECKING:
+    from grpc import ServicerContext
+
 T = TypeVar("T")
 
 
@@ -27,16 +30,22 @@ class SubscriptionManagerThread(Thread, Generic[T]):
         _, _, feature_id, _, _, target_id = origin_identifier.split("/")
         self.logger = logging.getLogger(f"{self.__class__.__name__}[{feature_id}.{target_id}]")
 
-    def add_subscription(self) -> Stream[T]:
+    def add_subscription(self, context: ServicerContext) -> Stream[T]:
         s = Stream()
 
         # send last item so clients receive the current status immediately
         if self.__last_item is not None:
             s.put(self.__last_item)
 
+        context.add_callback(lambda: self.cancel_subscription(s))
+
         self.__subscriber_streams.append(s)
         return s
 
+    def cancel_subscription(self, subscription: Stream[T]):
+        subscription.cancel()
+        self.__subscriber_streams.remove(subscription)
+
     def run(self):
         for item in self.__producer_stream:
             self.logger.info(f"Received item, forwarding to all subscribers: {item}")
